==> mythplugins_0.20.2.orig.tar.gz: mythplugins-0.20.2/mythweb/includes/mouseovers.php <==
<?php
/**
 * This allows you to create inline help items - popup tables linked to
 * mouseover events.  It requires the mouseovers.js file.
 *
 * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/includes/mouseovers.php $
 * @date        $Date: 2006-06-24 14:03:10 -0500 (Sat, 24 Jun 2006) $
 * @version     $Revision: 10290 $
 * @author      $Author: xris $
 * @license     GPL
 *
 * @package     MythWeb
 *
/**/

// Enable/Disable help messages
    if ($_GET['show_help'] == 'yes' || $_POST['show_help'] == 'yes')
        $_SESSION['show help'] = true;
    elseif ($_GET['show_help'] == 'no' || $_POST['show_help'] == 'no')
        $_SESSION['show help'] = false;

/*
    show_popup:
    Returns an id and mouseover code to display a popup over whatever
    element the id resides within.
*/
    function show_popup($id, $text, $popup_id = NULL, $class = 'popup', $wstatus = '') {
        global $Footnotes;
        if (!$Footnotes[$popup_id ? $popup_id : $id])
            $Footnotes[$popup_id ? $popup_id : $id] = '<div id="'.($popup_id ? $popup_id : $id)."_popup\" class=\"$class\">$text</div>";
    // $popup_id allows us to recycle certain info fields - it's ignored if empty
        $ret = " id=\"$id\" onmouseover=\"popup('$id', '$popup_id');";
        # This won't work until we add wstatus stuff to the javascript code, since it rewrites onmouseout
        #if ($wstatus) {
        #    $ret .= "wstatus('".str_replace('\'', '\\\'', $wstatus)
        #           ."');return true\" onmouseout=\"wstatus('foo');";
        #}
        $ret .= "return true\"";
        return $ret;
    }

/*
    show_help:
    This will create a link around $link that will bring up a popup
    div containing $text, which should be the help info for whatever
    $link relates to.
*/
    function show_help($link, $text, $url = '', $extras = '') {
        if ($url)
            $url = " href=\"$url\" ";
        if (!$_SESSION['show help']) {
            if ($url || $extras)
                echo "<a $url$extras>$link</a>";
            else
                echo $link;
            return;
        }
        static $help_count;
        $help_count++;
        echo '<a'.show_popup('helplink_'.$help_count, $text, NULL, 'help').'>'.$link.'</a>';
    }

/*
    generate_popup_menu:
    generates a popup
*/
    function generate_popup_menu($id, $class, $items, $overload = 0) {
        if ($overload >= 50) return '';
        if (!count($items))  return '';
        if ($id && $overload == 0) {
            $text = "<script language=\"JavaScript\" type=\"text/javascript\">\n"
                   ."<!--\n"
                   ."register_menu('$id');\n"
                   ."// -->\n"
                   ."</script>\n"
                   ."<ul id=\"$id\"";
        }
        else
            $text = '<ul';
        if ($class)
            $text .= " class=\"$class\"";
        $text .= ">\n";
        $sep = false;
        foreach ($items as $item) {
        // Normal menu item
            if (is_array($item) && isset($item['name'])) {
                $text .= str_repeat('  ', $overload+1) . '<li';
            // Separator above?
                if ($sep) {
                    $sep = false;
                    $text .= ' class="sep"';
                }
            // Print the content
                if ($item['url'])
                    $text .= "><a href=\"".$item['url'].'">'.$item['name'].'</a>';
                elseif ($item['click'])
                    $text .= '><a onclick="'.$item['click'].'">'.$item['name'].'</a>';
                else
                    $text .= '>'.$item['name'];
            // Child menu?
                if ($item['children'])
                    $text .= "\n".str_repeat('  ', $overload+2).generate_popup_menu('', '', $item['children'], $overload + 2)
                            .str_repeat('  ', $overload+2);
            // Close off the list item
                $text .= "</li>\n";
            }
        // Just a separator
            else
                $sep = true;
        }
        return $text.str_repeat('  ', $overload)."</ul>\n";
    }

==> mythplugins_0.21.0.orig.tar.gz: mythplugins-0.21/mythweb/includes/mouseovers.php <==
<?php
/**
 * This allows you to create inline help items - popup tables linked to
 * mouseover events.  It requires the mouseovers.js file.
 *
 * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/includes/mouseovers.php $
 * @date        $Date: 2008-03-08 21:09:11 +0000 (Sat, 08 Mar 2008) $
 * @version     $Revision: 16467 $
 * @author      $Author: xris $
 * @license     GPL
 *
 * @package     MythWeb
 *
/**/

// Enable/Disable help messages
    if (isset($_REQUEST['show_help'])) {
        if ($_REQUEST['show_help'] == 'yes')
            $_SESSION['show help'] = true;
        elseif ($_REQUEST['show_help'] == 'no')
            $_SESSION['show help'] = false;
    }

/*
    show_popup:
    Returns an id and mouseover code to display a popup over whatever
    element the id resides within.
*/
    function show_popup($id, $text, $popup_id = NULL, $css_class = 'popup', $wstatus = '') {
        global $Footnotes;
        $Footnotes[] =
            "\n"
           .'<script type="text/javascript">new Tip($("'.$id.'"), "'
           .str_replace(array("\n","\r",'"'),array('','',"'"),$text)
           .'", { className: "'.$css_class.'" });</script>';
        return ' id="'.$id.'"';
    }

/*
    show_help:
    This will create a link around $link that will bring up a popup
    div containing $text, which should be the help info for whatever
    $link relates to.
*/
    function show_help($link, $text, $url = '', $extras = '') {
        if ($url)
            $url = " href=\"$url\" ";
        if (!$_SESSION['show help']) {
            if ($url || $extras)
                echo "<a $url$extras>$link</a>";
            else
                echo $link;
            return;
        }
        static $help_count;
        $help_count++;
        echo '<a'.show_popup('helplink_'.$help_count, $text, NULL, 'help').'>'.$link.'</a>';
    }

/*
    generate_popup_menu:
    generates a popup
*/
    function generate_popup_menu($id, $css_class, $items, $overload = 0) {
        if ($overload >= 50) return '';
        if (!count($items))  return '';
        if ($id && $overload == 0) {
            $text = "<script language=\"JavaScript\" type=\"text/javascript\">\n"
                   ."<!--\n"
                   ."register_menu('$id');\n"
                   ."// -->\n"
                   ."</script>\n"
                   ."<ul id=\"$id\"";
        }
        else
            $text = '<ul';
        if ($css_class)
            $text .= " class=\"$css_class\"";
        $text .= ">\n";
        $sep = false;
        foreach ($items as $item) {
        // Normal menu item
            if (is_array($item) && isset($item['name'])) {
                $text .= str_repeat('  ', $overload+1) . '<li';
            // Separator above?
                if ($sep) {
                    $sep = false;
                    $text .= ' class="sep"';
                }
            // Print the content
                if ($item['url'])
                    $text .= "><a href=\"".$item['url'].'">'.$item['name'].'</a>';
                elseif ($item['click'])
                    $text .= '><a onclick="'.$item['click'].'">'.$item['name'].'</a>';
                else
                    $text .= '>'.$item['name'];
            // Child menu?
                if ($item['children'])
                    $text .= "\n".str_repeat('  ', $overload+2).generate_popup_menu('', '', $item['children'], $overload + 2)
                            .str_repeat('  ', $overload+2);
            // Close off the list item
                $text .= "</li>\n";
            }
        // Just a separator
            else
                $sep = true;
        }
        return $text.str_repeat('  ', $overload)."</ul>\n";
    }
